<?php
/**
 * Set up the default theme options
 *
 * @since 1.0.0
 */
function bavotasan_default_theme_options() {
	//delete_option( 'theme_mods_matheson_pro' );
	return array(
		'logo' => '',
		'width' => '992',
		'boxed' => 'on',
		'layout' => 'right',
		'primary' => 'col-md-8',
		'secondary' => 'col-md-2',
		'display_author' => 'on',
		'display_date' => 'on',
		'display_comment_count' => 'on',
		'display_categories' => 'on',
		'link_color' => '#428BCA',
		'link_hover_color' => '#2A6496',
		'main_text_color' => '#282828',
		'headers_color' => '#282828',
		'excerpt_content' => 'excerpt',
		'read_more_color' => 'default',
		'extended_footer_columns' => 'col-md-4',
		'copyright' => 'Copyright &copy; ' . date( 'Y' ) . ' <a href="' . home_url() . '">' . get_bloginfo( 'name' ) .'</a>. All Rights Reserved.',
		'main_text_font' => '"Open Sans", sans-serif',
		'main_text_font_size' => '16',
		'headers_font' => 'Raleway, sans-serif',
		'post_title_font' => 'Raleway, sans-serif',
		'post_title_font_size' => '32',
		'post_meta_font' => '"Open Sans", sans-serif',
		'post_meta_font_size' => '13',
		'jumbo_headline_title' => 'A great big headline to catch some attention, because everyone likes attention',
		'jumbo_headline_text' => 'So you understand the roaring wave of fear that swept through the greatest city in the world just as Monday was dawning--the stream of flight rising swiftly to a torrent, lashing in a foaming tumult round the railway stations, banked up into a horrible struggle about the shipping in the Thames, and hurrying by every available channel northward and eastward.  By ten o\'clock the police organisation, and by midday even the railway organisations, were losing coherency, losing shape and efficiency, guttering, softening, running at last in that swift liquefaction of the social body.',
		'jumbo_headline_button_text' => '',
		'jumbo_headline_button_link' => '',
		'jumbo_headline_button_color' => 'default',
	);
}

function bavotasan_theme_options() {
	$bavotasan_default_theme_options = bavotasan_default_theme_options();

	$return = array();
	foreach( $bavotasan_default_theme_options as $option => $value ) {
		$return[$option] = get_theme_mod( $option, $value );
	}

	return $return;
}

if ( class_exists( 'WP_Customize_Control' ) ) {
	class Bavotasan_Textarea_Control extends WP_Customize_Control {
	    public $type = 'textarea';

	    public function render_content() {
	        ?>
	        <label>
	        <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
	        <textarea rows="5" style="width:100%;" <?php $this->link(); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
	        </label>
	        <?php
	    }
	}

	class Bavotasan_Font_Control extends WP_Customize_Control {
	    public $type = 'select';
	    public $size = true;

	    public function render_content() {
			if ( empty( $this->choices ) )
				return;

			?>
			<label>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<select <?php $this->link(); ?>>
					<?php
					foreach ( $this->choices as $label => $choices ) {
						echo '<optgroup label="' . esc_attr( $label ) . '">';
						foreach ( $choices as $css_font => $font_name ) {
							echo '<option value="' . esc_attr( $css_font ) . '"' . selected( $this->value(), $css_font, false ) . '>' . $font_name . '</option>';
						}
						echo '</optgroup>';
					}
					?>
				</select>
			</label>
	        <?php if ( $this->size ) {
				?>
			<label>
				<input type="text" data-customize-setting-link="<?php echo $this->id . '_size'; ?>" style="width: 30px; margin-left: 5px;" /> px
			</label>
	        <?php
	        }
		}
	}

	class Bavotasan_Category_Dropdown_Control extends WP_Customize_Control {
		public function render_content() {
			$dropdown = wp_dropdown_categories( array(
				'name' => $this->id,
				'echo' => 0,
				'show_option_all' => __( 'All', 'matheson-pro' ),
				'selected' => $this->value(),
				'class' => 'customize-dropdown-cats',
			) );

			// hackily add in the data link parameter.
			$dropdown = str_replace( '<select', '<select ' . $this->get_link(), $dropdown );

			printf( '<label class="customize-control-select"><span class="customize-control-title">%s</span> %s</label>',
				$this->label,
				$dropdown
			);
		}
	}

	class Bavotasan_Post_Layout_Control extends WP_Customize_Control {
	    public function render_content() {
			if ( empty( $this->choices ) )
				return;

			$name = '_customize-radio-' . $this->id;

			?>
			<style>
			#customize-control-layout .customize-control-title {
				margin-bottom: 5px;
			}

			#customize-control-layout label {
				display: block;
				clear: both;
				margin-bottom: 10px;
				position: relative;
			}

			#customize-control-layout label input {
				display: inline-block;
				margin-top: -80px;
			}

			#customize-control-layout div {
				width: 124px;
				height: 84px;
				background: url(<?php echo BAVOTASAN_THEME_URL; ?>/library/images/layout.jpg) no-repeat 0 0;
				display: inline-block;
			}

			<?php if ( is_active_sidebar( 'second-sidebar' ) ) { ?>
			#customize-control-layout .left {
				background-position: 0 -250px;
			}

			#customize-control-layout .right {
				background-position: 0 -336px;
			}
			<?php } else { ?>
			#customize-control-layout .right {
				background-position: 0 -84px;
			}
			<?php } ?>
			#customize-control-layout .separate {
				background-position: 0 -168px;
			}
			</style>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<?php
			foreach ( $this->choices as $value => $label ) :
				?>
				<label>
					<input type="radio" value="<?php echo esc_attr( $value ); ?>" name="<?php echo esc_attr( $name ); ?>" <?php $this->link(); checked( $this->value(), $value ); ?> />
					<?php echo '<div class="' . esc_attr( $value ) . '"></div>'; ?>
				</label>
				<?php
			endforeach;
			echo '<p class="description">' . __( 'Sidebars only appear on single posts and pages. All other pages are full width.', 'matheson-pro' ) . '</p>';
	    }
	}
}

class Bavotasan_Customizer {
	public function __construct() {
		add_action( 'customize_register', array( $this, 'customize_register' ) );
		add_action( 'customize_preview_init', array( $this, 'customize_preview_init' ) );

		$mods = get_option( 'theme_mods_matheson_pro' );
		if ( empty( $mods ) )
			add_option( 'theme_mods_matheson_pro', get_option( 'matheson_pro_theme_options' ) );

	}

	public function customize_preview_init() {
		wp_enqueue_script( 'bavotasan_customizer', BAVOTASAN_THEME_URL . '/library/js/admin/customizer.js', array( 'jquery', 'customize-preview' ), '', true );
	}

	/**
	 * Adds theme options to the Customizer screen
	 *
	 * This function is attached to the 'customize_register' action hook.
	 *
	 * @param	class $wp_customize
	 *
	 * @since 1.0.0
	 */
	public function customize_register( $wp_customize ) {
		$bavotasan_default_theme_options = bavotasan_default_theme_options();

		$wp_customize->add_setting( 'logo', array(
			'default' => $bavotasan_default_theme_options['logo'],
            'sanitize_callback' => 'esc_url',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'logo', array(
			'label' => __( 'Site Logo', 'matheson-pro' ),
			'section' => 'title_tagline',
		) ) );

		// Layout section panel
		$wp_customize->add_section( 'bavotasan_layout', array(
			'title' => __( 'Layout', 'matheson-pro' ),
			'priority' => 35,
		) );

		$wp_customize->add_setting( 'boxed', array(
			'default' => $bavotasan_default_theme_options['boxed'],
            'sanitize_callback' => array( $this, 'sanitize_checkbox' ),
		) );

		$wp_customize->add_control( 'boxed', array(
			'label' => __( 'Boxed', 'matheson-pro' ),
			'section' => 'bavotasan_layout',
			'type' => 'checkbox',
			'priority' => 5,
		) );

		$wp_customize->add_setting( 'width', array(
			'default' => $bavotasan_default_theme_options['width'],
            'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'width', array(
			'label' => __( 'Site Width', 'matheson-pro' ),
			'section' => 'bavotasan_layout',
			'priority' => 10,
			'type' => 'select',
			'choices' => array(
				'1200' => __( '1200px', 'matheson-pro' ),
				'992' => __( '992px', 'matheson-pro' ),
			),
		) );

		$choices =  array(
			'col-md-2' => '17%',
			'col-md-3' => '25%',
			'col-md-4' => '34%',
			'col-md-5' => '42%',
			'col-md-6' => '50%',
			'col-md-7' => '58%',
			'col-md-8' => '66%',
			'col-md-9' => '75%',
			'col-md-10' => '83%',
		);

		$wp_customize->add_setting( 'primary', array(
			'default' => $bavotasan_default_theme_options['primary'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'primary', array(
			'label' => __( 'Main Content Width', 'matheson-pro' ),
			'section' => 'bavotasan_layout',
			'priority' => 15,
			'type' => 'select',
			'choices' => $choices,
		) );

		if ( is_active_sidebar( 'second-sidebar' ) ) {
			$wp_customize->add_setting( 'secondary', array(
				'default' => $bavotasan_default_theme_options['secondary'],
						'sanitize_callback' => 'esc_attr',
			) );

			$wp_customize->add_control( 'secondary', array(
				'label' => __( 'First Sidebar Width', 'matheson-pro' ),
				'section' => 'bavotasan_layout',
				'priority' => 20,
				'type' => 'select',
				'choices' => $choices,
			) );
		}

		$wp_customize->add_setting( 'layout', array(
			'default' => $bavotasan_default_theme_options['layout'],
            'sanitize_callback' => 'esc_attr',
		) );

		$layout_choices = array(
			'left' => __( 'Left', 'matheson-pro' ),
			'right' => __( 'Right', 'matheson-pro' ),
		);

		if ( is_active_sidebar( 'second-sidebar' ) )
			$layout_choices['separate'] = __( 'Separate', 'matheson-pro' );

		$wp_customize->add_control( new Bavotasan_Post_Layout_Control( $wp_customize, 'layout', array(
			'label' => __( 'Sidebar Layout', 'matheson-pro' ),
			'section' => 'bavotasan_layout',
			'size' => false,
			'priority' => 25,
			'choices' => $layout_choices,
		) ) );

		$wp_customize->add_setting( 'excerpt_content', array(
			'default' => $bavotasan_default_theme_options['excerpt_content'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'excerpt_content', array(
			'label' => __( 'Post Content Display', 'matheson-pro' ),
			'section' => 'bavotasan_layout',
			'priority' => 30,
			'type' => 'radio',
			'choices' => array(
				'excerpt' => __( 'Teaser Excerpt', 'matheson-pro' ),
				'content' => __( 'Full Content', 'matheson-pro' ),
			),
		) );

		$colors = array(
			'default' => __( 'Default', 'matheson-pro' ),
			'info' => __( 'Light Blue', 'matheson-pro' ),
			'primary' => __( 'Blue', 'matheson-pro' ),
			'danger' => __( 'Red', 'matheson-pro' ),
			'warning' => __( 'Yellow', 'matheson-pro' ),
			'success' => __( 'Green', 'matheson-pro' ),
		);

		$wp_customize->add_setting( 'read_more_color', array(
			'default' => $bavotasan_default_theme_options['read_more_color'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'read_more_color', array(
			'label' => __( 'Read More Button Color', 'matheson-pro' ),
			'section' => 'bavotasan_layout',
			'priority' => 34,
			'type' => 'select',
			'choices' => $colors,
		) );

		// Slider section panel
		$slider_settings = get_option( 'matheson_slider_settings' );

		$wp_customize->add_section( 'bavotasan_slider', array(
			'title' => __( 'Home Page Slider', 'matheson-pro' ),
			'priority' => 37,
			'description' => sprintf( __( 'For more slider options go to the %sHome Page Slider%s admin page.', 'matheson-pro' ), '<a href="' . admin_url( 'themes.php?page=slider_page' ) . '">', '</a>' ),
		) );

		$wp_customize->add_setting( 'matheson_slider_settings[display]', array(
			'default' => $slider_settings['display'],
			'type' => 'option',
            'sanitize_callback' => array( $this, 'sanitize_checkbox' ),
		) );

		$wp_customize->add_control( 'bavotasan_slider_display', array(
			'label' => __( 'Display', 'matheson-pro' ),
			'section' => 'bavotasan_slider',
			'settings' => 'matheson_slider_settings[display]',
			'priority' => 5,
			'type' => 'checkbox',
		) );

		$wp_customize->add_setting( 'matheson_slider_settings[autoplay]', array(
			'default' => $slider_settings['autoplay'],
			'type' => 'option',
            'sanitize_callback' => array( $this, 'sanitize_checkbox' ),
		) );

		$wp_customize->add_control( 'bavotasan_slider_autoplay', array(
			'label' => __( 'Autoplay', 'matheson-pro' ),
			'section' => 'bavotasan_slider',
			'settings' => 'matheson_slider_settings[autoplay]',
			'priority' => 7,
			'type' => 'checkbox',
		) );

		$wp_customize->add_setting( 'matheson_slider_settings[category]', array(
			'default' => $slider_settings['category'],
			'type' => 'option',
            'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( new Bavotasan_Category_Dropdown_Control( $wp_customize, 'category', array(
			'label' => __( 'Category', 'matheson-pro' ),
			'section' => 'bavotasan_slider',
			'settings' => 'matheson_slider_settings[category]',
			'priority' => 9,
		) ) );

		$wp_customize->add_setting( 'matheson_slider_settings[number]', array(
			'default' => $slider_settings['number'],
			'type' => 'option',
            'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'bavotasan_slider_number', array(
			'label' => __( 'Number', 'matheson-pro' ),
			'section' => 'bavotasan_slider',
			'settings' => 'matheson_slider_settings[number]',
			'priority' => 10,
		) );

		$wp_customize->add_setting( 'matheson_slider_settings[interval]', array(
			'default' => $slider_settings['interval'],
			'type' => 'option',
            'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'bavotasan_slider_interval', array(
			'label' => __( 'Interval', 'matheson-pro' ),
			'section' => 'bavotasan_slider',
			'settings' => 'matheson_slider_settings[interval]',
			'priority' => 30,
		) );

		// Jumbo headline section panel
		$wp_customize->add_section( 'bavotasan_jumbo', array(
			'title' => __( 'Jumbo Headline', 'matheson-pro' ),
			'priority' => 36,
			'description' => __( 'This section appears below the slider/header image on the home page. To remove it just delete all the content from the Title textarea.', 'matheson-pro' ),
		) );

		$wp_customize->add_setting( 'jumbo_headline_title', array(
			'default' => $bavotasan_default_theme_options['jumbo_headline_title'],
            'sanitize_callback' => 'esc_textarea',
		) );

		$wp_customize->add_control( new Bavotasan_Textarea_Control( $wp_customize, 'jumbo_headline_title', array(
			'label' => __( 'Title', 'matheson-pro' ),
			'section' => 'bavotasan_jumbo',
			'priority' => 26,
			'type' => 'text',
		) ) );

		$wp_customize->add_setting( 'jumbo_headline_text', array(
			'default' => $bavotasan_default_theme_options['jumbo_headline_text'],
            'sanitize_callback' => 'esc_textarea',
		) );

		$wp_customize->add_control( new Bavotasan_Textarea_Control( $wp_customize, 'jumbo_headline_text', array(
			'label' => __( 'Text', 'matheson-pro' ),
			'section' => 'bavotasan_jumbo',
			'priority' => 27,
			'type' => 'text',
		) ) );

		$wp_customize->add_setting( 'jumbo_headline_button_text', array(
			'default' => $bavotasan_default_theme_options['jumbo_headline_button_text'],
            'sanitize_callback' => 'sanitize_text_field',
		) );

		$wp_customize->add_control( 'jumbo_headline_button_text', array(
			'label' => __( 'Button Text', 'matheson-pro' ),
			'section' => 'bavotasan_jumbo',
			'priority' => 28,
			'type' => 'text',
		) );

		$wp_customize->add_setting( 'jumbo_headline_button_link', array(
			'default' => $bavotasan_default_theme_options['jumbo_headline_button_link'],
            'sanitize_callback' => 'esc_url',
		) );

		$wp_customize->add_control( 'jumbo_headline_button_link', array(
			'label' => __( 'Button Link', 'matheson-pro' ),
			'section' => 'bavotasan_jumbo',
			'priority' => 29,
			'type' => 'text',
		) );

		$wp_customize->add_setting( 'jumbo_headline_button_color', array(
			'default' => $bavotasan_default_theme_options['jumbo_headline_button_color'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'jumbo_headline_button_color', array(
			'label' => __( 'Button Color', 'matheson-pro' ),
			'section' => 'bavotasan_jumbo',
			'priority' => 30,
			'type' => 'select',
			'choices' => $colors,
		) );

		// Fonts panel
		$mixed_fonts = array(
			'Websafe Fonts' => array(
				'Arial, Helvetica, sans-serif' => 'Arial',
				'"Copperplate Light", "Copperplate Gothic Light", serif' => 'Copperplate Light',
				'"Courier New", Courier, monospace' => 'Courier New',
				'Futura, "Century Gothic", AppleGothic, sans-serif' => 'Futura',
				'Georgia, Times, "Times New Roman", serif' => 'Georgia',
				'"Gill Sans", Calibri, "Trebuchet MS", sans-serif' => 'Gill Sans',
				'"Helvetica Neue", Helvetica, Arial, sans-serif' => 'Helvetica Neue',
				'Impact, Haettenschweiler, "Arial Narrow Bold", sans-serif' => 'Impact',
				'"Lucida Sans", "Lucida Grande", "Lucida Sans Unicode", sans-serif' => 'Lucida',
				'Palatino, "Palatino Linotype", Georgia, Times, "Times New Roman", serif' => 'Palatino',
				'Tahoma, Geneva, Verdana, sans-serif' => 'Tahoma',
				'"Times New Roman", Times, Georgia, serif' => 'Times New Roman',
				'"Trebuchet MS", Tahoma, Arial, sans-serif' => 'Trebuchet',
				'Verdana, Geneva, Tahoma, sans-serif' => 'Verdana',
			),
			'Google Fonts' => bavotasan_google_fonts(),
		);

		$wp_customize->add_section( 'bavotasan_fonts', array(
			'title' => __( 'Fonts', 'matheson-pro' ),
			'priority' => 40,
		) );

		$wp_customize->add_setting( 'main_text_font', array(
			'default' => $bavotasan_default_theme_options['main_text_font'],
            'sanitize_callback' => 'sanitize_text_field',
		) );

		$wp_customize->add_setting( 'main_text_font_size', array(
			'default' => $bavotasan_default_theme_options['main_text_font_size'],
            'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( new Bavotasan_Font_Control( $wp_customize, 'main_text_font', array(
			'label' => __( 'Main Text', 'matheson-pro' ),
			'section' => 'bavotasan_fonts',
			'priority' => 10,
			'choices' => $mixed_fonts,
		) ) );

		$wp_customize->add_setting( 'headers_font', array(
			'default' => $bavotasan_default_theme_options['headers_font'],
            'sanitize_callback' => 'sanitize_text_field',
		) );

		$wp_customize->add_control( new Bavotasan_Font_Control( $wp_customize, 'headers_font', array(
			'label' => __( 'Headers (h1, h2, h3, etc...)', 'matheson-pro' ),
			'section' => 'bavotasan_fonts',
			'size' => false,
			'priority' => 15,
			'choices' => $mixed_fonts,
		) ) );

		$wp_customize->add_setting( 'post_title_font', array(
			'default' => $bavotasan_default_theme_options['post_title_font'],
            'sanitize_callback' => 'sanitize_text_field',
		) );

		$wp_customize->add_setting( 'post_title_font_size', array(
			'default' => $bavotasan_default_theme_options['post_title_font_size'],
            'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( new Bavotasan_Font_Control( $wp_customize, 'post_title_font', array(
			'label' => __( 'Post Title', 'matheson-pro' ),
			'section' => 'bavotasan_fonts',
			'priority' => 30,
			'choices' => $mixed_fonts,
		) ) );

		$wp_customize->add_setting( 'post_meta_font', array(
			'default' => $bavotasan_default_theme_options['post_meta_font'],
            'sanitize_callback' => 'sanitize_text_field',
		) );

		$wp_customize->add_setting( 'post_meta_font_size', array(
			'default' => $bavotasan_default_theme_options['post_meta_font_size'],
            'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( new Bavotasan_Font_Control( $wp_customize, 'post_meta_font', array(
			'label' => __( 'Post Meta', 'matheson-pro' ),
			'section' => 'bavotasan_fonts',
			'priority' => 35,
			'choices' => $mixed_fonts,
		) ) );

		// Color panel
		$wp_customize->add_setting( 'headers_color', array(
			'default' => $bavotasan_default_theme_options['headers_color'],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'headers_color', array(
			'label' => __( 'Headers (h1, h2, h3, etc...)', 'matheson-pro' ),
			'section'  => 'colors',
			'priority' => 20,
		) ) );

		$wp_customize->add_setting( 'main_text_color', array(
			'default' => $bavotasan_default_theme_options['main_text_color'],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'main_text_color', array(
			'label' => __( 'Main Text Color', 'matheson-pro' ),
			'section'  => 'colors',
			'priority' => 25,
		) ) );

		$wp_customize->add_setting( 'link_color', array(
			'default' => $bavotasan_default_theme_options['link_color'],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'link_color', array(
			'label' => __( 'Link Color', 'matheson-pro' ),
			'section'  => 'colors',
			'priority' => 50,
		) ) );

		$wp_customize->add_setting( 'link_hover_color', array(
			'default' => $bavotasan_default_theme_options['link_hover_color'],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'link_hover_color', array(
			'label' => __( 'Link Hover Color', 'matheson-pro' ),
			'section'  => 'colors',
			'priority' => 55,
		) ) );

		// Posts panel
		$wp_customize->add_section( 'bavotasan_posts', array(
			'title' => __( 'Posts', 'matheson-pro' ),
			'priority' => 45,
		) );

		$wp_customize->add_setting( 'display_categories', array(
			'default' => $bavotasan_default_theme_options['display_categories'],
            'sanitize_callback' => array( $this, 'sanitize_checkbox' ),
		) );

		$wp_customize->add_control( 'display_categories', array(
			'label' => __( 'Display Categories', 'matheson-pro' ),
			'section' => 'bavotasan_posts',
			'type' => 'checkbox',
		) );

		$wp_customize->add_setting( 'display_author', array(
			'default' => $bavotasan_default_theme_options['display_author'],
            'sanitize_callback' => array( $this, 'sanitize_checkbox' ),
		) );

		$wp_customize->add_control( 'display_author', array(
			'label' => __( 'Display Author', 'matheson-pro' ),
			'section' => 'bavotasan_posts',
			'type' => 'checkbox',
		) );

		$wp_customize->add_setting( 'display_date', array(
			'default' => $bavotasan_default_theme_options['display_date'],
            'sanitize_callback' => array( $this, 'sanitize_checkbox' ),
		) );

		$wp_customize->add_control( 'display_date', array(
			'label' => __( 'Display Date', 'matheson-pro' ),
			'section' => 'bavotasan_posts',
			'type' => 'checkbox',
		) );

		$wp_customize->add_setting( 'display_comment_count', array(
			'default' => $bavotasan_default_theme_options['display_comment_count'],
            'sanitize_callback' => array( $this, 'sanitize_checkbox' ),
		) );

		$wp_customize->add_control( 'display_comment_count', array(
			'label' => __( 'Display Comment Count', 'matheson-pro' ),
			'section' => 'bavotasan_posts',
			'type' => 'checkbox',
		) );

		// Footer panel
		$wp_customize->add_section( 'bavotasan_footer', array(
			'title' => __( 'Footer', 'matheson-pro' ),
			'priority' => 50,
		) );

		$wp_customize->add_setting( 'extended_footer_columns', array(
			'default' => $bavotasan_default_theme_options['extended_footer_columns'],
			'transport' => 'postMessage',
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'extended_footer_columns', array(
			'label' => __( 'Extended Footer Columns', 'matheson-pro' ),
			'section' => 'bavotasan_footer',
			'priority' => 10,
			'type' => 'select',
			'choices' => array(
				'col-md-12' => __( '1 Column', 'matheson-pro' ),
				'col-md-6' => __( '2 Columns', 'matheson-pro' ),
				'col-md-4' => __( '3 Columns', 'matheson-pro' ),
				'col-md-3' => __( '4 Columns', 'matheson-pro' ),
				'col-md-2' => __( '6 Columns', 'matheson-pro' ),
			),
		) );

		$wp_customize->add_setting( 'copyright', array(
			'default' => $bavotasan_default_theme_options['copyright'],
            'sanitize_callback' => 'esc_textarea',
		) );

		$wp_customize->add_control( new Bavotasan_Textarea_Control( $wp_customize, 'copyright', array(
			'label' => __( 'Copyright Notice', 'matheson-pro' ),
			'section' => 'bavotasan_footer',
			'priority' => 20,
		) ) );
	}

	/**
	 * Sanitize checkbox options
	 *
	 * @since 1.0.1
	 */
    public function sanitize_checkbox( $value ) {
        if ( 'on' != $value )
            $value = false;

        return $value;
    }
}
$bavotasan_customizer = new Bavotasan_Customizer;

/**
 * Prepare font CSS
 *
 * @param	string $font  The select font
 *
 * @since 1.0.0
 */
function bavotasan_prepare_font( $font ) {
	$font_family = ( 'Lato Light, sans-serif' == $font ) ? 'Lato' : $font;
	$font_family = ( 'Arvo Bold, serif' == $font ) ? 'Arvo' : $font_family;
	$font_weight = ( 'Lato Light, sans-serif' == $font ) ? ' font-weight: 300' : 'font-weight: normal';
	$font_weight = ( 'Lato, sans-serif' == $font ) ? ' font-weight: 400' : $font_weight;
	$font_weight = ( 'Lato Bold, sans-serif' == $font || 'Arvo Bold, serif' == $font ) ? ' font-weight: 900' : $font_weight;

	return 'font-family: ' . html_entity_decode( $font_family ) . '; ' . $font_weight;
}

function bavotasan_google_fonts() {
	return array(
        'Arvo, serif' => 'Arvo',
        'Arvo Bold, serif' => 'Arvo Bold',
        'Copse, sans-serif' => 'Copse',
        '"Droid Sans", sans-serif' => 'Droid Sans',
        '"Droid Serif", serif' => 'Droid Serif',
        'Exo, sans-serif' => 'Exo',
        'Lato Light, sans-serif' => 'Lato Light',
        'Lato, sans-serif' => 'Lato',
        'Lato Bold, sans-serif' => 'Lato Bold',
        'Lobster, cursive' => 'Lobster',
        'Nobile, sans-serif' => 'Nobile',
        '"Open Sans", sans-serif' => 'Open Sans',
        'Oswald, sans-serif' => 'Oswald',
        'Pacifico, cursive' => 'Pacifico',
        'Raleway, sans-serif' => 'Raleway',
        'Rokkitt, serif' => 'Rokkit',
        '"Russo One", sans-serif' => 'Russo One',
        '"PT Sans", sans-serif' => 'PT Sans',
        'Quicksand, sans-serif' => 'Quicksand',
        'Quattrocento, serif' => 'Quattrocento',
        'Ubuntu, sans-serif' => 'Ubuntu',
        '"Yanone Kaffeesatz", sans-serif' => 'Yanone Kaffeesatz',
    );
}